Learn R Programming

JSTORr (version 1.0.20160103)

unpack1grams: unpack1grams

Description

Full-length articles from the Journal of Archaeological Reseach

Usage

data(unpack1grams)
#' unpack2grams
Full-length articles from the Journal of Archaeological Reseach
A dataset containing the full text of full-length articles published in the Journal of Archaeological Reseach. Obtained from dfr.jstor.org

Arguments

Format

Returns a list of two items. First is "wordcounts", a Document Term Matrix of 1-grams for 232 articles, and second is 'bibliodata', a data frame of bibliographic information for all 232 articles.

Details

A dataset containing the full text of full-length articles published in the Journal of Archaeological Reseach. Obtained from dfr.jstor.org